@@ -37,6 +37,7 @@ const (
 	modifyPrefix     = "modify_"
 	oncePrefix       = "once_"
 	privatePrefix    = "private_"
+	readOnlyPrefix   = "readonly_"
 	removePrefix     = "remove_"
 	runPrefix        = "run_"
 	symlinkPrefix    = "symlink_"
@@ -57,13 +58,13 @@ const (
 )
 
 var (
-	dirPrefixRegexp  = regexp.MustCompile(`\A(dot|exact|literal|private)_`)
-	filePrefixRegexp = regexp.MustCompile(`\A(after|before|create|dot|empty|encrypted|executable|literal|modify|once|private|remove|run|symlink)_`)
+	dirPrefixRegexp  = regexp.MustCompile(`\A(dot|exact|literal|readonly|private)_`)
+	filePrefixRegexp = regexp.MustCompile(`\A(after|before|create|dot|empty|encrypted|executable|literal|modify|once|private|readonly|remove|run|symlink)_`)
 	fileSuffixRegexp = regexp.MustCompile(`\.(literal|tmpl)\z`)
 )
 
 // knownPrefixedFiles is a set of known filenames with the .chezmoi prefix.
-var knownPrefixedFiles = newStringSet(
+var knownPrefixedFiles = NewStringSet(
 	Prefix+".json"+TemplateSuffix,
 	Prefix+".toml"+TemplateSuffix,
 	Prefix+".yaml"+TemplateSuffix,
@@ -136,7 +137,7 @@ func SHA256Sum(data []byte) []byte {
 func SuspiciousSourceDirEntry(base string, info fs.FileInfo) bool {
 	switch info.Mode().Type() {
 	case 0:
-		return strings.HasPrefix(base, Prefix) && !knownPrefixedFiles.contains(base)
+		return strings.HasPrefix(base, Prefix) && !knownPrefixedFiles.Contains(base)
 	case fs.ModeDir:
 		return strings.HasPrefix(base, Prefix) && base != templatesDirName
 	case fs.ModeSymlink:
