@@ -2,7 +2,6 @@ package chezmoi
 
 import (
 	"errors"
-	"os"
 	"os/exec"
 	"testing"
 
@@ -18,12 +17,7 @@ func TestGPGEncryption(t *testing.T) {
 	}
 	require.NoError(t, err)
 
-	tempDir, err := os.MkdirTemp("", "chezmoi-test-gpg")
-	require.NoError(t, err)
-	defer func() {
-		require.NoError(t, os.RemoveAll(tempDir))
-	}()
-
+	tempDir := t.TempDir()
 	key, passphrase, err := chezmoitest.GPGGenerateKey(command, tempDir)
 	require.NoError(t, err)
 
