@@ -10,6 +10,7 @@ type dumpCmdConfig struct {
 	exclude   *chezmoi.EntryTypeSet
 	format    writeDataFormat
 	include   *chezmoi.EntryTypeSet
+	init      bool
 	recursive bool
 }
 
@@ -29,6 +30,7 @@ func (c *Config) newDumpCmd() *cobra.Command {
 	flags.VarP(c.dump.exclude, "exclude", "x", "Exclude entry types")
 	flags.VarP(&c.dump.format, "format", "f", "Set output format")
 	flags.VarP(c.dump.include, "include", "i", "Include entry types")
+	flags.BoolVar(&c.dump.init, "init", c.update.init, "Recreate config file from template")
 	flags.BoolVarP(&c.dump.recursive, "recursive", "r", c.dump.recursive, "Recurse into subdirectories")
 
 	return dumpCmd
@@ -38,7 +40,9 @@ func (c *Config) runDumpCmd(cmd *cobra.Command, args []string) error {
 	dumpSystem := chezmoi.NewDumpSystem()
 	if err := c.applyArgs(cmd.Context(), dumpSystem, chezmoi.EmptyAbsPath, args, applyArgsOptions{
 		include:   c.dump.include.Sub(c.dump.exclude),
+		init:      c.dump.init,
 		recursive: c.dump.recursive,
+		umask:     c.Umask,
 	}); err != nil {
 		return err
 	}
