@@ -15,6 +15,7 @@ type editCmdConfig struct {
 	apply   bool
 	exclude *chezmoi.EntryTypeSet
 	include *chezmoi.EntryTypeSet
+	init    bool
 }
 
 func (c *Config) newEditCmd() *cobra.Command {
@@ -37,6 +38,7 @@ func (c *Config) newEditCmd() *cobra.Command {
 	flags.BoolVarP(&c.Edit.apply, "apply", "a", c.Edit.apply, "Apply after editing")
 	flags.VarP(c.Edit.exclude, "exclude", "x", "Exclude entry types")
 	flags.VarP(c.Edit.include, "include", "i", "Include entry types")
+	flags.BoolVar(&c.Edit.init, "init", c.update.init, "Recreate config file from template")
 
 	return editCmd
 }
@@ -49,6 +51,7 @@ func (c *Config) runEditCmd(cmd *cobra.Command, args []string, sourceState *chez
 		if c.Edit.apply {
 			if err := c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, noArgs, applyArgsOptions{
 				include:      c.Edit.include.Sub(c.Edit.exclude),
+				init:         c.Edit.init,
 				recursive:    true,
 				umask:        c.Umask,
 				preApplyFunc: c.defaultPreApplyFunc,
@@ -67,34 +70,28 @@ func (c *Config) runEditCmd(cmd *cobra.Command, args []string, sourceState *chez
 	}
 
 	editorArgs := make([]string, 0, len(targetRelPaths))
-	var decryptedDirAbsPath chezmoi.AbsPath
 	type transparentlyDecryptedFile struct {
 		sourceAbsPath    chezmoi.AbsPath
 		decryptedAbsPath chezmoi.AbsPath
 	}
 	var transparentlyDecryptedFiles []transparentlyDecryptedFile
+TARGETRELPATH:
 	for _, targetRelPath := range targetRelPaths {
 		sourceStateEntry := sourceState.MustEntry(targetRelPath)
 		sourceRelPath := sourceStateEntry.SourceRelPath()
-		var editorArg string
-		if sourceStateFile, ok := sourceStateEntry.(*chezmoi.SourceStateFile); ok && sourceStateFile.Attr.Encrypted {
-			if decryptedDirAbsPath.Empty() {
-				decryptedDir, err := os.MkdirTemp("", "chezmoi-decrypted")
-				if err != nil {
-					return err
-				}
-				decryptedDirAbsPath = chezmoi.NewAbsPath(decryptedDir)
-				defer func() {
-					_ = c.baseSystem.RemoveAll(decryptedDirAbsPath)
-				}()
-				if runtime.GOOS != "windows" {
-					if err := c.baseSystem.Chmod(decryptedDirAbsPath, 0o700); err != nil {
-						return err
-					}
-				}
+		switch sourceStateFile, ok := sourceStateEntry.(*chezmoi.SourceStateFile); {
+		case ok && sourceStateFile.Attr.Encrypted:
+			// FIXME in the case that the file is an encrypted template then we
+			// should first decrypt the file to a temporary directory and
+			// secondly add a hardlink from the edit directory to the temporary
+			// directory.
+
+			tempDirAbsPath, err := c.tempDir("chezmoi-encrypted")
+			if err != nil {
+				return err
 			}
 			// FIXME use RawContents and DecryptFile
-			decryptedAbsPath := decryptedDirAbsPath.Join(sourceRelPath.TargetRelPath(c.encryption.EncryptedSuffix()))
+			decryptedAbsPath := tempDirAbsPath.Join(sourceRelPath.TargetRelPath(c.encryption.EncryptedSuffix()))
 			contents, err := sourceStateFile.Contents()
 			if err != nil {
 				return err
@@ -110,12 +107,48 @@ func (c *Config) runEditCmd(cmd *cobra.Command, args []string, sourceState *chez
 				decryptedAbsPath: decryptedAbsPath,
 			}
 			transparentlyDecryptedFiles = append(transparentlyDecryptedFiles, transparentlyDecryptedFile)
-			editorArg = decryptedAbsPath.String()
-		} else {
+			editorArgs = append(editorArgs, decryptedAbsPath.String())
+		case ok && runtime.GOOS != "windows":
+			// If the operating system supports hard links and the file is not
+			// encrypted, then create a hard link to the file in the source
+			// directory in the temporary edit directory. This means that the
+			// editor will see the target filename while simultaneously updating
+			// the file in the source directory.
+
+			// Compute the hard link path from the target path. If the file is a
+			// template then preserve the .tmpl suffix as a clue to the editor.
+			targetRelPath := sourceRelPath.TargetRelPath(c.encryption.EncryptedSuffix())
+			if sourceStateFile.Attr.Template {
+				targetRelPath += chezmoi.TemplateSuffix
+			}
+			tempDirAbsPath, err := c.tempDir("chezmoi-edit")
+			if err != nil {
+				return err
+			}
+			hardlinkAbsPath := tempDirAbsPath.Join(targetRelPath)
+
+			// Attempt to create the hard link. If this succeeds, continue to
+			// the next target. Hardlinking will fail if the temporary directory
+			// is on a different filesystem to the source directory, which is
+			// not the case for most users.
+			//
+			// FIXME create a temporary directory on the same filesystem as the
+			// source directory if needed.
+			if err := os.MkdirAll(hardlinkAbsPath.Dir().String(), 0o700); err != nil {
+				return err
+			}
+			if err := c.baseSystem.Link(c.SourceDirAbsPath.Join(sourceRelPath.RelPath()), hardlinkAbsPath); err == nil {
+				editorArgs = append(editorArgs, hardlinkAbsPath.String())
+				continue TARGETRELPATH
+			}
+
+			// Otherwise, fall through to the default option of editing the
+			// source file in the source state.
+			fallthrough
+		default:
 			sourceAbsPath := c.SourceDirAbsPath.Join(sourceRelPath.RelPath())
-			editorArg = sourceAbsPath.String()
+			editorArgs = append(editorArgs, sourceAbsPath.String())
 		}
-		editorArgs = append(editorArgs, editorArg)
 	}
 
 	if err := c.runEditor(editorArgs); err != nil {
@@ -135,6 +168,7 @@ func (c *Config) runEditCmd(cmd *cobra.Command, args []string, sourceState *chez
 	if c.Edit.apply {
 		if err := c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, args, applyArgsOptions{
 			include:      c.Edit.include,
+			init:         c.Edit.init,
 			recursive:    false,
 			umask:        c.Umask,
 			preApplyFunc: c.defaultPreApplyFunc,
