@@ -189,7 +189,7 @@ func (c *Config) runUpgradeCmd(cmd *cobra.Command, args []string) error {
 	// Execute the new version.
 	arg0 := path
 	argv := []string{arg0, "--version"}
-	log.Debug().
+	log.Info().
 		Str("arg0", arg0).
 		Strs("argv", argv).
 		Msg("exec")
@@ -281,7 +281,7 @@ func (c *Config) getLibc() (string, error) {
 
 func (c *Config) replaceExecutable(ctx context.Context, executableFilenameAbsPath chezmoi.AbsPath, releaseVersion *semver.Version, rr *github.RepositoryRelease) error {
 	goos := runtime.GOOS
-	if goos == "linux" {
+	if goos == "linux" && runtime.GOARCH == "amd64" {
 		libc, err := c.getLibc()
 		if err != nil {
 			return err
@@ -372,18 +372,9 @@ func (c *Config) upgradePackage(ctx context.Context, rr *github.RepositoryReleas
 		}
 
 		// Create a temporary directory for the package.
-		var tempDirAbsPath chezmoi.AbsPath
-		if c.dryRun {
-			tempDirAbsPath = chezmoi.NewAbsPath(os.TempDir())
-		} else {
-			tempDir, err := os.MkdirTemp("", "chezmoi")
-			if err != nil {
-				return err
-			}
-			tempDirAbsPath = chezmoi.NewAbsPath(tempDir)
-			defer func() {
-				_ = c.baseSystem.RemoveAll(tempDirAbsPath)
-			}()
+		tempDirAbsPath, err := c.tempDir("chezmoi")
+		if err != nil {
+			return err
 		}
 
 		data, err := c.downloadURL(ctx, releaseAsset.GetBrowserDownloadURL())
